TransH
======

.. currentmodule:: pykeen.models

.. autoclass:: TransH
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransH.hpo_default
      ~TransH.regularizer_default_kwargs
      ~TransH.relation_regularizer_default_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: regularizer_default_kwargs
   .. autoattribute:: relation_regularizer_default_kwargs
